Module console

Module console 

Console input and output.

Functions

read_bytes
Reads bytes from the console into the given mutable slice.
write_bytes
Writes given bytes to the console.
write_text_bytes
Writes text bytes to the console, expanding line feeds to CRLF.