pub fn write_text_bytes(bytes: &[u8])Expand description
Writes text bytes to the console, expanding line feeds to CRLF.
This is intended for human-readable console output. Use write_bytes for
raw byte transport.
pub fn write_text_bytes(bytes: &[u8])Writes text bytes to the console, expanding line feeds to CRLF.
This is intended for human-readable console output. Use write_bytes for
raw byte transport.