pub unsafe fn write_kernel_page_table(root_paddr: PhysAddr)Expand description
Writes the register to update the current page table root for kernel space
(TTBR1_EL1).
When the “arm-el2” feature is enabled, TTBR0_EL2 is dedicated to the Hypervisor’s Stage-2 page table base address.
Note that the TLB is NOT flushed after this operation.
Safety
This function is unsafe as it changes the virtual memory address space.