Console input and output.
Functions
- read_
bytes - Reads bytes from the console into the given mutable slice.
- write_
bytes - Writes given bytes to the console.
- write_
text_ bytes - Writes text bytes to the console, expanding line feeds to CRLF.