#[repr(C)]pub struct TaskContext {}Expand description
Saved hardware states of a task.
The context usually includes:
- Callee-saved registers
- Stack pointer register
- Thread pointer register (for kernel-space thread-local storage)
- FP/SIMD registers
On context switch, current task saves its context from CPU to memory, and the next task restores its context from memory to CPU.
Fields
sp: u64r19: u64r20: u64r21: u64r22: u64r23: u64r24: u64r25: u64r26: u64r27: u64r28: u64r29: u64lr: u64tpidr_el0: u64Thread Pointer
Implementations
Sourceimpl TaskContext
impl TaskContext
Sourcepub fn new() -> TaskContext
pub fn new() -> TaskContext
Sourcepub fn init(&mut self, entry: usize, kstack_top: VirtAddr, tls_area: VirtAddr)
pub fn init(&mut self, entry: usize, kstack_top: VirtAddr, tls_area: VirtAddr)
Initializes the context for a new task, with the given entry point and kernel stack.
Sourcepub fn switch_to(&mut self, next_ctx: &TaskContext)
pub fn switch_to(&mut self, next_ctx: &TaskContext)
Switches to another task.
It first saves the current task’s context from CPU to this place, and then
restores the next task’s context from next_ctx to CPU.